Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Messager ¶
type Messager struct {
Webhook string
}
func NewMessager ¶
NewMessager function creates and returns a new instance of the Messager struct.
type Options ¶
type System ¶
func New ¶
New function Creates a new system instance with the specified notification system and options.
Click to show internal directories.
Click to hide internal directories.